]> git.sesse.net Git - cubemap/blobdiff - server.h
Add suppor for raw (non-Metacube) inputs over HTTP. Only really useful for TS.
[cubemap] / server.h
index 79c35f82e8bf065a9fe9e7f6bff33ef8eb3b6a23..320fcbcd8da8a274277a9633fbc0e0f1ca95a90c 100644 (file)
--- a/server.h
+++ b/server.h
@@ -55,12 +55,14 @@ public:
        // at the same time).
        CubemapStateProto serialize();
        void add_client_from_serialized(const ClientProto &client);
-       int add_stream(const std::string &url, size_t bytes_received, size_t prebuffering_bytes, Stream::Encoding encoding);
+       int add_stream(const std::string &url, size_t bytes_received, size_t prebuffering_bytes, Stream::Encoding encoding, Stream::Encoding src_encoding);
        int add_stream_from_serialized(const StreamProto &stream, int data_fd);
        int lookup_stream_by_url(const std::string &url) const;
        void set_backlog_size(int stream_index, size_t new_size);
        void set_prebuffering_bytes(int stream_index, size_t new_amount);
        void set_encoding(int stream_index, Stream::Encoding encoding);
+       void set_src_encoding(int stream_index, Stream::Encoding encoding);
+       void add_gen204(const std::string &url, const std::string &allow_origin);
 
 private:
        // Mutex protecting queued_add_clients.
@@ -87,7 +89,10 @@ private:
        std::vector<Stream *> streams;
 
        // Map from URL to index into <streams>.
-       std::map<std::string, int> url_map;
+       std::map<std::string, int> stream_url_map;
+
+       // Map from URL to CORS Allow-Origin header (or empty string).
+       std::map<std::string, std::string> ping_url_map;
 
        // Map from file descriptor to client.
        std::map<int, Client> clients;
@@ -130,7 +135,7 @@ private:
        // Close a given client socket, and clean up after it.
        void close_client(Client *client);
 
// Parse the HTTP request. Returns a HTTP status code (200/400/404).
        int parse_request(Client *client);
 
        // Construct the HTTP header, and set the client into
@@ -138,9 +143,12 @@ private:
        void construct_header(Client *client);
 
        // Construct a generic error with the given line, and set the client into
-       // the SENDING_ERROR state.
+       // the SENDING_SHORT_RESPONSE state.
        void construct_error(Client *client, int error_code);
 
+       // Construct a 204, and set the client into the SENDING_SHORT_RESPONSE state.
+       void construct_204(Client *client);
+
        void process_queued_data();
        void skip_lost_data(Client *client);
@@ -130,7 +135,7 @@ private:
        void close_client(Client *client);
 
-       // Parse the HTTP request. Returns a HTTP status code (200/400/404).
+       // Parse the HTTP request. Returns a HTTP status code (200/204/400/404).
        int parse_request(Client *client);
 